@@ -12,6 +12,7 @@ method.B <- function(alpha = 0.05, path.in = "~/", path.out = "~/",
                      ask = FALSE, plot.bxp = FALSE, fence = 2,
                      data = NULL, option = 2) {
   exec <- strftime(Sys.time(), usetz=TRUE)
+  if (!missing(ext)) ext <- tolower(ext) # case-insensitive
   ret  <- CV.calc(alpha=alpha, path.in=path.in, path.out=path.out,
                   file=file, set=set, ext=ext, na=na, sep=sep,
                   dec=dec, logtrans=logtrans, ola=ola,
@@ -55,14 +56,13 @@ method.B <- function(alpha = 0.05, path.in = "~/", path.out = "~/",
     DF    <- EMA.B$tTable["treatmentT", "DF"]
     if (verbose) {
       name <- paste0(file, set)
-      cat("\nData set", paste0(name,
-          ": Method B by lme (option=2; ",
-          "equivalent to SAS\u2019 DDFM=CONTAIN)"),
-          paste0("\n", paste0(rep("\u2500", 70+nchar(name)), collapse="")), "\n")
-      print(anova(modB), digits=6)
+      cat("\nData set", paste0(name, ": Method B (option = 2) by lme()"),
+          paste0("\n", paste0(rep("\u2500", 41+nchar(name)), collapse="")), "\n")
+      if (logtrans) cat("Response: log(PK)\n") else cat("\nResponse: logPK\n")
+      print(anova(modB), digits=6, signif.stars=FALSE)
       cat("\ntreatment T \u2013 R:\n")
-      print(signif(EMA.B$tTable["treatmentT", ], 7))
-      cat("\n")
+      print(signif(EMA.B$tTable["treatmentT", c(1:2, 4:5)], 5))
+      cat(DF, "Degrees of Freedom (equivalent to SAS\u2019 DDFM=CONTAIN)\n\n")
     }
   } else {              # by lmer/lmerTest (Satterthwaite's or Kenward-Roger DF)
     if (logtrans) {     # use the raw data and log-transform internally
@@ -77,27 +77,30 @@ method.B <- function(alpha = 0.05, path.in = "~/", path.out = "~/",
     } else {
       EMA.B <- summary(modB, ddf="Kenward-Roger")
     }
-    PE    <- EMA.B$coefficients["treatmentT", "Estimate"]
-    CI    <- exp(PE + c(-1, +1) *
-                 qt(1-alpha, EMA.B$coef["treatmentT", "df"]) *
-                 EMA.B$coef["treatmentT", "Std. Error"])
-    DF    <- EMA.B$coefficients["treatmentT", "df"]
+    PE <- EMA.B$coefficients["treatmentT", "Estimate"]
+    CI <- exp(PE + c(-1, +1) *
+              qt(1-alpha, EMA.B$coef["treatmentT", "df"]) *
+              EMA.B$coef["treatmentT", "Std. Error"])
+    DF <- EMA.B$coefficients["treatmentT", "df"]
     if (verbose) {
       if (option == 1) {
-         cat("\nData set", paste0(file, set,
-             ": Method B by lmer (option=1; equivalent to SAS\u2019 DDFM=SATTERTHWAITE)"),
-            paste0("\n", paste0(rep("\u2500", 81), collapse="")), "\n")
-        print(anova(modB, ddf="Satterthwaite"))
+        cat("\nData set", paste0(file, set, ": Method B (option = 1) by lmer()"),
+            paste0("\n", paste0(rep("\u2500", 46), collapse="")), "\n")
+        if (logtrans) cat("Response: log(PK)\n") else cat("\nResponse: logPK\n")
+        print(anova(modB, ddf="Satterthwaite"), digits=6, signif.stars=FALSE)
+        cat("\ntreatment T \u2013 R:\n")
+        print(signif(EMA.B$coefficients["treatmentT", c(1:2, 4:5)], 5))
+        cat(signif(DF, 6), "Degrees of Freedom (equivalent to SAS\u2019 DDFM=SATTERTHWAITE)\n\n")
       } else {
-        df.txt <- "3; equivalent to SAS\u2019 DDFM=KENWARDROGER)"
-        cat("\nData set", paste0(file, set,
-            ": Method B by lmer (option=3; equivalent to SAS\u2019 DDFM=KENWARDROGER)"),
-            paste0("\n", paste0(rep("\u2500", 80), collapse="")), "\n")
-        print(anova(modB, ddf="Kenward-Roger"))
-     }
-      cat("\ntreatment T \u2013 R:\n")
-      print(signif(EMA.B$coefficients["treatmentT", ], 7))
-      cat("\n")
+        df.txt <- "3; equivalent to Stata\u2019s dfm=Kenward Roger EIM)"
+        cat("\nData set", paste0(file, set, ": Method B (option = 3) by lmer()"),
+            paste0("\n", paste0(rep("\u2500", 46), collapse="")), "\n")
+        if (logtrans) cat("Response: log(PK)\n") else cat("\nResponse: logPK\n")
+        print(anova(modB, ddf="Kenward-Roger"), digits=6, signif.stars=FALSE)
+        cat("\ntreatment T \u2013 R:\n")
+        print(signif(EMA.B$coefficients["treatmentT", c(1:2, 4:5)], 5))
+        cat(signif(DF, 6), "Degrees of Freedom (equivalent to Stata\u2019s dfm=Kenward Roger EIM)\n\n")
+      }
     }
   } # end of evaluation by option=2 (lme) or option=1/3 (lmer)
   PE  <- exp(PE)
@@ -108,25 +111,25 @@ method.B <- function(alpha = 0.05, path.in = "~/", path.out = "~/",
                     DF, ret$CVwT, ret$CVwR, ret$sw.ratio,
                     ret$sw.ratio.upper, ret$BE1, ret$BE2, CI[1], CI[2],
                     PE, "fail", "fail", "fail", log(CI[2])-log(PE),
-                    paste0(ret$ol, collapse="|"), ret$CVwR.new,
-                    ret$sw.ratio.new, ret$sw.ratio.new.upper, ret$BE.new1,
-                    ret$BE.new2, "fail", "fail", "fail",
+                    paste0(ret$ol, collapse="|"), ret$CVwR.rec,
+                    ret$sw.ratio.rec, ret$sw.ratio.rec.upper, ret$BE.rec1,
+                    ret$BE.rec2, "fail", "fail", "fail",
                     stringsAsFactors=FALSE)
   names(res)<- c("Design", "Method", "n", "nTT", "nRR", "Sub/seq",
                  "Miss/seq", "Miss/per", "alpha", "DF", "CVwT(%)",
-                 "CVwR(%)", "sw.ratio", "sw.ratio.CL", "EL.lo(%)",
-                 "EL.hi(%)", "CI.lo(%)", "CI.hi(%)", "PE(%)",
+                 "CVwR(%)", "sw.ratio", "sw.ratio.CL", "L(%)",
+                 "U(%)", "CL.lo(%)", "CL.hi(%)", "PE(%)",
                  "CI", "GMR", "BE", "log.half-width", "outlier",
-                 "CVwR.new(%)", "sw.ratio.new", "sw.ratio.new.CL",
-                 "EL.new.lo(%)", "EL.new.hi(%)",
-                 "CI.new", "GMR.new", "BE.new")
+                 "CVwR.rec(%)", "sw.ratio.rec", "sw.ratio.rec.CL",
+                 "L.rec(%)", "U.rec(%)",
+                 "CI.rec", "GMR.rec", "BE.rec")
   if (ret$BE2 == 1.25) { # change column names if not scaling
-    colnames(res)[which(names(res) == "EL.lo(%)")] <- "BE.lo(%)"
-    colnames(res)[which(names(res) == "EL.hi(%)")] <- "BE.hi(%)"
+    colnames(res)[which(names(res) == "L(%)")] <- "BE.lo(%)"
+    colnames(res)[which(names(res) == "U(%)")] <- "BE.hi(%)"
   }
-  if (!is.na(ret$BE.new2) & ret$BE.new2 == 1.25) { # change column names if not scaling
-    colnames(res)[which(names(res) == "EL.new.lo(%)")] <- "BE.new.lo(%)"
-    colnames(res)[which(names(res) == "EL.new.hi(%)")] <- "BE.new.hi(%)"
+  if (!is.na(ret$BE.rec2) & ret$BE.rec2 == 1.25) { # change column names if not scaling
+    colnames(res)[which(names(res) == "L.rec(%)")] <- "BE.rec.lo(%)"
+    colnames(res)[which(names(res) == "U.rec(%)")] <- "BE.rec.hi(%)"
   }
   # Convert CVs, limits, PE, and CI (up to here as fractions) to percent
   res$"CVwT(%)" <- 100*res$"CVwT(%)"
@@ -135,46 +138,46 @@ method.B <- function(alpha = 0.05, path.in = "~/", path.out = "~/",
     res$"BE.lo(%)" <- 100*res$"BE.lo(%)"
     res$"BE.hi(%)" <- 100*res$"BE.hi(%)"
   } else {                          # expanded limits
-    res$"EL.lo(%)" <- 100*res$"EL.lo(%)"
-    res$"EL.hi(%)" <- 100*res$"EL.hi(%)"
+    res$"L(%)" <- 100*res$"L(%)"
+    res$"U(%)" <- 100*res$"U(%)"
   }
-  if (!is.na(res$"CVwR.new(%)")) { # only if recalculated CVwR
-    res$"CVwR.new(%)" <- 100*res$"CVwR.new(%)"
-    if ("BE.new.lo(%)" %in% names(res)) { # conventional limits
-      res$"BE.new.lo(%)" <- 100*res$"BE.new.lo(%)"
-      res$"BE.new.hi(%)" <- 100*res$"BE.new.hi(%)"
+  if (!is.na(res$"CVwR.rec(%)")) { # only if recalculated CVwR
+    res$"CVwR.rec(%)" <- 100*res$"CVwR.rec(%)"
+    if ("BE.rec.lo(%)" %in% names(res)) { # conventional limits
+      res$"BE.rec.lo(%)" <- 100*res$"BE.rec.lo(%)"
+      res$"BE.rec.hi(%)" <- 100*res$"BE.rec.hi(%)"
     } else {                              # expanded limits
-      res$"EL.new.lo(%)" <- 100*res$"EL.new.lo(%)"
-      res$"EL.new.hi(%)" <- 100*res$"EL.new.hi(%)"
+      res$"L.rec(%)" <- 100*res$"L.rec(%)"
+      res$"U.rec(%)" <- 100*res$"U.rec(%)"
     }
   }
   res$"PE(%)"    <- 100*res$"PE(%)"
-  res$"CI.lo(%)" <- 100*res$"CI.lo(%)"
-  res$"CI.hi(%)" <- 100*res$"CI.hi(%)"
-  if (round(res$"CI.lo(%)", 2) >= 100*ret$BE1 &
-      round(res$"CI.hi(%)", 2) <= 100*ret$BE2)
+  res$"CL.lo(%)" <- 100*res$"CL.lo(%)"
+  res$"CL.hi(%)" <- 100*res$"CL.hi(%)"
+  if (round(res$"CL.lo(%)", 2) >= 100*ret$BE1 &
+      round(res$"CL.hi(%)", 2) <= 100*ret$BE2)
     res$CI <- "pass"  # CI within acceptance range
   if (round(res$"PE(%)", 2) >= 80 & round(res[["PE(%)"]], 2) <= 125)
     res$GMR <- "pass" # PE within 80.00-125.00%
   if (res$CI == "pass" & res$GMR == "pass")
     res$BE <- "pass"  # if passing both, conclude BE
-  if (!is.na(res$"CVwR.new(%)")) {
-    if (round(res$"CI.lo(%)", 2) >= 100*ret$BE.new1 &
-        round(res$"CI.hi(%)", 2) <= 100*ret$BE.new2)
-      res$CI.new <- "pass"  # CI within acceptance range
-    res$GMR.new <- res$GMR
-    if (res$CI.new == "pass" & res$GMR.new == "pass")
-      res$BE.new <- "pass"  # if passing both, conclude BE
+  if (!is.na(res$"CVwR.rec(%)")) {
+    if (round(res$"CL.lo(%)", 2) >= 100*ret$BE.rec1 &
+        round(res$"CL.hi(%)", 2) <= 100*ret$BE.rec2)
+      res$CI.rec <- "pass"  # CI within acceptance range
+    res$GMR.rec <- res$GMR
+    if (res$CI.rec == "pass" & res$GMR.rec == "pass")
+      res$BE.rec <- "pass"  # if passing both, conclude BE
   }
   if (details) { # results in default (7 digits) precision
     ret <- res
     if (as.character(res$outlier) == "NA") {
       # remove superfluous columns if ola=FALSE or ola=TRUE
       # and no outlier(s) detected
-      ret <- ret[ , !names(ret) %in% c("outlier", "CVwR.new(%)",
-                                       "sw.ratio.new", "EL.new.lo(%)",
-                                       "EL.new.hi(%)", "CI.new",
-                                       "GMR.new", "BE.new")]
+      ret <- ret[ , !names(ret) %in% c("outlier", "CVwR.rec(%)",
+                                       "sw.ratio.rec", "L.rec(%)",
+                                       "U.rec(%)", "CI.rec",
+                                       "GMR.rec", "BE.rec")]
     }
     #class(ret) <- "repBE"
     return(ret)
@@ -186,20 +189,20 @@ method.B <- function(alpha = 0.05, path.in = "~/", path.out = "~/",
     res$"BE.lo(%)" <- round(res$"BE.lo(%)", 2)
     res$"BE.hi(%)" <- round(res$"BE.hi(%)", 2)
   } else {                          # expanded limits
-    res$"EL.lo(%)" <- round(res$"EL.lo(%)", 2)
-    res$"EL.hi(%)" <- round(res$"EL.hi(%)", 2)
+    res$"L(%)" <- round(res$"L(%)", 2)
+    res$"U(%)" <- round(res$"U(%)", 2)
   }
   res$"PE(%)"    <- round(res$"PE(%)", 2)
-  res$"CI.lo(%)" <- round(res$"CI.lo(%)", 2)
-  res$"CI.hi(%)" <- round(res$"CI.hi(%)", 2)
-  if (!is.na(res$"CVwR.new(%)")) { # only if recalculated CVwR
-  res$"CVwR.new(%)" <- round(res$"CVwR.new(%)", 2)
-    if ("BE.new.lo(%)" %in% names(res)) { # conventional limits
-      res$"BE.new.lo(%)" <- round(res$"BE.new.lo(%)", 2)
-      res$"BE.new.hi(%)" <- round(res$"BE.new.hi(%)", 2)
+  res$"CL.lo(%)" <- round(res$"CL.lo(%)", 2)
+  res$"CL.hi(%)" <- round(res$"CL.hi(%)", 2)
+  if (!is.na(res$"CVwR.rec(%)")) { # only if recalculated CVwR
+  res$"CVwR.rec(%)" <- round(res$"CVwR.rec(%)", 2)
+    if ("BE.rec.lo(%)" %in% names(res)) { # conventional limits
+      res$"BE.rec.lo(%)" <- round(res$"BE.rec.lo(%)", 2)
+      res$"BE.rec.hi(%)" <- round(res$"BE.rec.hi(%)", 2)
     } else {                          # expanded limits
-      res$"EL.new.lo(%)" <- round(res$"EL.new.lo(%)", 2)
-      res$"EL.new.hi(%)" <- round(res$"EL.new.hi(%)", 2)
+      res$"L.rec(%)" <- round(res$"L.rec(%)", 2)
+      res$"U.rec(%)" <- round(res$"U.rec(%)", 2)
     }
   }
   overwrite <- TRUE # default
@@ -230,14 +233,14 @@ method.B <- function(alpha = 0.05, path.in = "~/", path.out = "~/",
   insert.str <- paste0(insert.str, "\nalpha              :   ", alpha,
                 " (", 100*(1-2*alpha), "% CI)\n")
   txt <- paste0(left.str, insert.str, right.str)
-  if (!is.na(res$"CVwR.new(%)")) {
+  if (!is.na(res$"CVwR.rec(%)")) {
     txt1 <- paste0("\n\nAssessment based on original CVwR",
                    sprintf(" %.2f%%", res$"CVwR(%)"))
     txt <- paste0(txt, txt1, "\n", paste0(rep("\u2500", nchar(txt1)-2), collapse=""))
   }
   txt <- paste0(txt,
                 "\nConfidence interval: ", sprintf("%6.2f%% ... %6.2f%%",
-                                                   res$"CI.lo(%)", res$"CI.hi(%)"),
+                                                   res$"CL.lo(%)", res$"CL.hi(%)"),
                 "  ", res$CI,
                 "\nPoint estimate     : ", sprintf("%6.2f%%", res$"PE(%)"),
                 "              ", res$GMR,
@@ -245,15 +248,15 @@ method.B <- function(alpha = 0.05, path.in = "~/", path.out = "~/",
   txt <- paste0(txt,
                 repBE.draw.line(called.from="ABEL", L=ret$BE1, U=ret$BE2,
                                 lo=CI[1], hi=CI[2], PE=PE), "\n")
-  if (!is.na(res$"CVwR.new(%)")) {
+  if (!is.na(res$"CVwR.rec(%)")) {
     txt1 <- paste0("\nAssessment based on recalculated CVwR",
-                   sprintf(" %.2f%%", res$"CVwR.new(%)"))
+                   sprintf(" %.2f%%", res$"CVwR.rec(%)"))
     txt <- paste0(txt, txt1, "\n", paste0(rep("\u2500", nchar(txt1)-1), collapse=""))
-    txt <- paste0(txt, "\nConfidence interval: ", res$CI.new,
-                  "\nPoint estimate     : ", res$GMR.new,
-                  "\nMixed (CI & PE)    : ", res$BE.new, "\n")
+    txt <- paste0(txt, "\nConfidence interval: ", res$CI.rec,
+                  "\nPoint estimate     : ", res$GMR.rec,
+                  "\nMixed (CI & PE)    : ", res$BE.rec, "\n")
     txt <- paste0(txt,
-                  repBE.draw.line(called.from="ABEL", L=ret$BE.new1, U=ret$BE.new2,
+                  repBE.draw.line(called.from="ABEL", L=ret$BE.rec1, U=ret$BE.rec2,
                                   lo=CI[1], hi=CI[2], PE=PE), "\n")
   }
   if (res$Design == "TRR|RTR")
@@ -263,10 +266,10 @@ method.B <- function(alpha = 0.05, path.in = "~/", path.out = "~/",
   if (res$Design %in% c("TRTR|RTRT|TRRT|RTTR", "TRRT|RTTR|TTRR|RRTT"))
     txt <- paste0(txt, "Note: Confounded effects; design not recommended.\n")
   if (print & overwrite) {
-    res.file <- file(description=results, open="ab")
-    res.str  <- txt # UNIXes LF
-    if (os == "Windows") res.str <- gsub("\n", "\r\n", txt) # CRLF
-    if (os == "Darwin")  res.str <- gsub("\n", "\r", txt)   # CR
+    res.file <- file(results, open="ab")                        # line endings
+    res.str  <- txt                                             # LF (UNIXes, Solaris)
+    if (os == "Windows") res.str <- gsub("\n", "\r\n", res.str) # CRLF (Windows)
+    if (os == "Darwin")  res.str <- gsub("\n", "\r", res.str)   # CR (OSX)
     writeBin(charToRaw(res.str), res.file)
     close(res.file)
   }
